# About Polly Validator

This is a data validation package to check the dataset level and sample level metadata for errors.

# Installation

Polly-python can be installed by running:

```python
pip install polly-validator
```
